@@ -14,16 +14,17 @@ class BiLSTMAttention(pl.LightningModule):
     https://colab.research.google.com/drive/1jX8mvJ_8oulueGEMmLg3is5qRdhuDmgz#scrollTo=4YGiToFOZgXx
     """
 
-    def __init__(self,vocab_size=100, dim=10,n_hidden=10,out_num_classes=10,embedding_enabled=False):
+    def __init__(self,vocab_size=8021, dim=10,n_hidden=10,out_num_classes=10,embedding_enabled=False,attention=True,**kwargs):
         """[summary]
         实现简单的双向长短记忆
 
         Args:
-            vocab_size (int, optional): [description]. Defaults to 100.
-            dim (int, optional): [description]. Defaults to 10.
-            n_hidden (int, optional): [description]. Defaults to 10.
-            out_num_classes (int, optional): [description]. Defaults to 10.
-            embedding_enabled (bool, optional): [description]. Defaults to False.
+            vocab_size (int, optional): [字典大小 建议使用 https://github.com/CLUEbenchmark/CLUECorpus2020 里的词典8021，可以有效降低模型大小]. Defaults to 8021.
+            dim (int, optional): [维度]. Defaults to 10.
+            n_hidden (int, optional): [隐藏层]. Defaults to 10.
+            out_num_classes (int, optional): [输出的维度]. Defaults to 10.
+            embedding_enabled (bool, optional): [是否启用编码层]. Defaults to False.
+            attention (bool, optional): [是启用注意力]. Defaults to False.
         """
         super().__init__()
         self.save_hyperparameters()
@@ -58,6 +59,9 @@ class BiLSTMAttention(pl.LightningModule):
         # final_hidden_state, final_cell_state : [num_layers(=1) * num_directions(=2), batch_size, n_hidden]
         output, (final_hidden_state, final_cell_state) = self.lstm(input, (hidden_state, cell_state))
         output = output.permute(1, 0, 2) # output : [batch_size, len_seq, n_hidden]
-        attn_output, attention = self.attention_net(output, final_hidden_state)
-        out=self.out(attn_output)
-        return output,out, attention # output hidden_state : [batch_size, len_seq, n_hidden] model : [batch_size, num_classes], attention : [batch_size, n_step]
+        if self.hparams.attention:
+            attn_output, attention = self.attention_net(output, final_hidden_state)
+            out=self.out(attn_output)
+            return output,out, attention # output hidden_state : [batch_size, len_seq, n_hidden] model : [batch_size, num_classes], attention : [batch_size, n_step]
+        else:
+            return output
